@@ -15,6 +15,9 @@ from uuid import uuid4
 from .socket_response import ensure_socket_response
 from datetime import datetime
 
+from . import log_conf
+log_conf.init()
+
 
 class Node(FastAPI):
     name: str
@@ -22,6 +25,8 @@ class Node(FastAPI):
 
     def __init__(self, name: str, uuid: str = None):
         super().__init__()
+        self.log = logging.getLogger()
+
         host = os.environ.get('LOOP_HOST', None) or os.environ.get('HOST', 'learning-loop.ai')
         self.ws_url = f'ws{"s" if host != "backend" else ""}://' + host
 
@@ -147,7 +152,12 @@ class Node(FastAPI):
     def _activate_asyncio_warnings() -> None:
         '''Produce warnings for coroutines which take too long on the main loop and hence clog the event loop'''
         try:
-            loop = asyncio.get_running_loop()
+            import sys
+            if sys.version_info.major >= 3 and sys.version_info.minor >= 7:  # most
+                loop = asyncio.get_running_loop()
+            else:
+                loop = asyncio.get_event_loop()
+
             loop.set_debug(True)
             loop.slow_callback_duration = 0.2
             logging.info('activated asyncio warnings')
